@@ -8,14 +8,18 @@ from djangoldp.models import Model
 from django.utils.text import slugify
 from django.utils.translation import ugettext_lazy as _
 
-from djangoldp_community.permissions import CommunityPermissions
+from djangoldp_community.permissions import CommunityPermissions, CommunityCirclePermissions, \
+    CommunityProjectPermissions
+from djangoldp_community.views import CommunityMembersViewset
 
 from djangoldp_circle.models import Circle
 from djangoldp_project.models import Project
 from djangoldp_joboffer.models import JobOffer
 
 class Community(Model):
-    name = models.CharField(max_length=255, blank=True)
+    name = models.CharField(max_length=255, blank=True, help_text="Changing a community's name is highly discouraged")
+    logo = models.URLField(blank=True, null=True)
+    allow_self_registration = models.BooleanField(default=False)
     slug = models.SlugField(unique=True, blank=True, null=True)
 
     def __str__(self):
@@ -25,12 +29,13 @@ class Community(Model):
         verbose_name = _('community')
         verbose_name_plural = _("communities")
         permission_classes = [CommunityPermissions]
-        anonymous_perms = []
-        authenticated_perms = []
+        anonymous_perms = ['view']
+        authenticated_perms = ['inherit', 'add']
+        superuser_perms = ['view']
         lookup_field = 'slug'
         container_path = "/communities/"
         ordering = ['slug']
-        serializer_fields = ['@id', 'name', 'projects', 'circles', 'members', 'joboffers']
+        serializer_fields = ['@id', 'name', 'logo', 'allow_self_registration', 'projects', 'circles', 'members', 'joboffers']
         rdf_type = "sib:Community"
 
 class CommunityMember(Model):
@@ -41,9 +46,11 @@ class CommunityMember(Model):
     class Meta(Model.Meta):
         verbose_name = _('community member')
         verbose_name_plural = _("community members")
+        view_set = CommunityMembersViewset
         permission_classes = [CommunityPermissions]
-        anonymous_perms = []
-        authenticated_perms = []
+        anonymous_perms = ['view', 'add']
+        authenticated_perms = ['inherit']
+        superuser_perms = ['view', 'add']
         container_path = "community-members/"
         serializer_fields = ['@id', 'community', 'user', 'is_admin']
         rdf_type = "as:items"
@@ -55,9 +62,10 @@ class CommunityCircle(Model):
     class Meta(Model.Meta):
         verbose_name = _('community circle')
         verbose_name_plural = _("community circles")
-        permission_classes = [CommunityPermissions]
+        permission_classes = [CommunityPermissions, CommunityCirclePermissions]
         anonymous_perms = []
         authenticated_perms = []
+        superuser_perms = []
         container_path = "community-circles/"
         serializer_fields = ['@id', 'community', 'circle']
         rdf_type = "as:items"
@@ -69,9 +77,10 @@ class CommunityProject(Model):
     class Meta(Model.Meta):
         verbose_name = _('community project')
         verbose_name_plural = _("community projects")
-        permission_classes = [CommunityPermissions]
+        permission_classes = [CommunityPermissions, CommunityProjectPermissions]
         anonymous_perms = []
         authenticated_perms = []
+        superuser_perms = []
         container_path = "community-projects/"
         serializer_fields = ['@id', 'community', 'project']
         rdf_type = "as:items"
@@ -86,6 +95,7 @@ class CommunityJobOffer(Model):
         permission_classes = [CommunityPermissions]
         anonymous_perms = []
         authenticated_perms = []
+        superuser_perms = []
         container_path = "community-joboffers/"
         serializer_fields = ['@id', 'community', 'joboffer']
         rdf_type = "as:items"
@@ -97,7 +107,7 @@ def pre_create_account(sender, instance, **kwargs):
             if Community.objects.filter(slug=slugify(instance.name)).count() > 0:
                 raise Exception(_("Name already taken"))
             setattr(instance, Model.slug_field(instance), slugify(instance.name))
+            setattr(instance, "urlid", "")
     else:
         # Is a distant object, generate a random slug
         setattr(instance, Model.slug_field(instance), uuid.uuid4().hex.upper()[0:8])
-
